@@ -12,8 +12,8 @@ if sys.version_info[0] >= 3:   # pragma: no cover
     import configparser
     from urllib.parse import urlparse
     from collections import UserDict
+    from collections.abc import Mapping
     from inspect import getfullargspec as getargspec
-    from unittest import mock
 else:  # pragma: no cover
     string_types = basestring,
     text_type = unicode
@@ -23,4 +23,4 @@ else:  # pragma: no cover
     from urlparse import urlparse
     from UserDict import UserDict
     from inspect import getargspec
-    import mock
+    from collections import Mapping
