@@ -19,7 +19,7 @@ from rasterio.env import Env, defenv, delenv, getenv, setenv, ensure_env, ensure
 from rasterio.env import GDALVersion, require_gdal_version
 from rasterio.errors import EnvError, RasterioIOError, GDALVersionError
 from rasterio.rio.main import main_group
-from rasterio.session import AWSSession, DummySession, OSSSession
+from rasterio.session import AWSSession, DummySession, OSSSession, SwiftSession
 
 from .conftest import requires_gdal21
 
@@ -819,6 +819,35 @@ def test_oss_session_credentials(gdalenv):
         assert getenv()['OSS_ENDPOINT'] == 'null-island-1'
 
 
+def test_swift_session_credentials(gdalenv):
+    """Create an Env with a oss session."""
+    swift_session = SwiftSession(
+        swift_storage_url='foo',
+        swift_auth_token='bar')
+    with rasterio.env.Env(session=swift_session) as s:
+        s.credentialize()
+        assert getenv()['SWIFT_STORAGE_URL'] == 'foo'
+        assert getenv()['SWIFT_AUTH_TOKEN'] == 'bar'
+
+
+def test_swift_session_by_user_key():
+    def mock_init(self, session=None, 
+                swift_storage_url=None, swift_auth_token=None, 
+                swift_auth_v1_url=None, swift_user=None, swift_key=None):
+        self._creds = {'SWIFT_STORAGE_URL':'foo',
+                       'SWIFT_AUTH_TOKEN':'bar'}
+
+    with mock.patch('rasterio.session.SwiftSession.__init__', new=mock_init):
+        swift_session = SwiftSession(
+            swift_auth_v1_url='foo',
+            swift_user='bar',
+            swift_key='key')
+        with rasterio.env.Env(session=swift_session) as s:
+            s.credentialize()
+            assert getenv()['SWIFT_STORAGE_URL'] == 'foo'
+            assert getenv()['SWIFT_AUTH_TOKEN'] == 'bar'
+
+
 def test_dummy_session_without_boto3(monkeypatch, caplog):
     """Without boto3, always revert to dummy session"""
     # Confirm fix of #1708.
